@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Inline::Module;
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 our $API_VERSION = 'v2';
 
 use Carp 'croak';
@@ -16,7 +16,6 @@ sub DEBUG { if (DEBUG_ON) { print "DEBUG >>> ", sprintf(@_), "\n" }}
 
 #------------------------------------------------------------------------------
 # This import serves multiple roles:
-# - -MInline::Module=autostub
 # - ::Inline module's proxy to Inline.pm
 # - Makefile.PL postamble
 # - Makefile rule support
@@ -36,6 +35,7 @@ sub import {
     }
     elsif ($program eq 'Build.PL') {
         $class->check_inc_inc($program);
+        return;
     }
 
     return unless @_;
@@ -43,8 +43,6 @@ sub import {
 
     return $class->handle_stub($stub_module, @_)
         if $cmd eq 'stub';
-    return $class->handle_autostub(@_)
-        if $cmd eq 'autostub';
     return $class->handle_makestub(@_)
         if $cmd eq 'makestub';
     return $class->handle_distdir(@ARGV)
@@ -52,6 +50,11 @@ sub import {
     return $class->handle_fixblib()
         if $cmd eq 'fixblib';
 
+    # TODO: Deprecated 12/26/2014. Remove this in a month.
+    die "Inline::Module 'autostub' no longer supported. " .
+        "Remove this option from PERL5OPT."
+            if $cmd eq 'autostub';
+
     die "Unknown Inline::Module::import argument '$cmd'"
 }
 
@@ -183,45 +186,6 @@ sub handle_makestub {
     exit 0;
 }
 
-sub handle_autostub {
-    my ($class, @args) = @_;
-
-    # Don't mess with Perl tools, while using PERL5OPT and autostub:
-    return unless
-        $0 eq '-e' or
-        defined $ENV{_} and $ENV{_} =~ m!/prove[^/]*$!;
-    # Don't autostub in the distdir:
-    return if -e './inc/Inline/Module.pm';
-
-    DEBUG_ON && DEBUG "Inline::Module::autostub(@_)";
-
-    require lib;
-    lib->import('lib');
-
-    my %autostub_modules;
-    for my $arg (@args) {
-        if ($arg =~ m!::!) {
-            $autostub_modules{$arg} = 1;
-        }
-        else {
-            croak "Unknown 'autostub' argument: '$arg'";
-        }
-    }
-
-    push @INC, sub {
-        my ($this, $module) = @_;
-        delete $ENV{PERL5OPT};
-
-        $module =~ s!\.pm$!!;
-        $module =~ s!/!::!g;
-        $autostub_modules{$module} or return;
-
-        my $code = $class->proxy_module($module);
-        open my $fh, '<', \$code;
-        return $fh;
-    }
-}
-
 sub handle_distdir {
     my ($class, $distdir, @args) = @_;
     my $stub_modules = [];
@@ -359,9 +323,7 @@ sub proxy_module {
     my ($class, $module) = @_;
 
     return <<"...";
-# DO NOT EDIT
-#
-# GENERATED BY: Inline::Module $Inline::Module::VERSION
+# DO NOT EDIT. GENERATED BY: Inline::Module
 #
 # This module is for author-side development only. When this module is shipped
 # to CPAN, it will be automagically replaced with content that does not
@@ -381,19 +343,16 @@ use Inline::Module stub => '$API_VERSION';
 sub dyna_module {
     my ($class, $module) = @_;
     return <<"...";
-# DO NOT EDIT
-#
-# GENERATED BY: Inline::Module $Inline::Module::VERSION
+# DO NOT EDIT. GENERATED BY: Inline::Module $Inline::Module::VERSION
 
 use strict; use warnings;
 package $module;
 use base 'DynaLoader';
 bootstrap $module;
-
 1;
 ...
 
-# XXX - think about this later:
+# TODO: Add XS VERSION checking support:
 # our \$VERSION = '0.0.5';
 # bootstrap $module \$VERSION;
 }
